@@ -47,13 +47,8 @@ struct fio_file {
 	struct flist_head hash_list;
 	enum fio_filetype filetype;
 
-	/*
-	 * A file may not be a file descriptor, let the io engine decide
-	 */
-	union {
-		unsigned long file_data;
-		int fd;
-	};
+	void *file_data;
+	int fd;
 
 	/*
 	 * filename and possible memory mapping
