@@ -31,6 +31,8 @@ enum {
 	B_TYPE_DISCARD,
 	B_TYPE_READVOID,
 	B_TYPE_WRITEZERO,
+	B_TYPE_READBARRIER,
+	B_TYPE_WRITEBARRIER,
 	B_TYPE_NR
 };
 
